# Version file autogenerated by the build process
version = '0.13.2'
build = 1255
vcs_info = 'Git SHA1 0341c62b committed on 2023-10-10'
package_name = 'ksconf'

if __name__ == '__main__':
    print('KSCONF_VERSION="0.13.2"\nKSCONF_BUILD="1255"\nKSCONF_VCS_INFO="Git SHA1 0341c62b committed on 2023-10-10"')
